repeat

Function repeat 

pub const fn repeat(byte: u8) -> Repeat
Creates an instance of a reader that infinitely repeats one byte.

All reads from this reader will succeed by filling the specified buffer with the given byte.

See std::io::repeat() for more details.