BufWriter

Struct BufWriter 

pub struct BufWriter<W: ?Sized + Write> { /* private fields */ }
Wraps a writer and buffers its output.

See std::io::BufWriter for more details.

Implementations

Source

impl<W: Write> BufWriter<W>

pub fn new(inner: W) -> BufWriter<W>

Creates a new BufWriter<W> with a default buffer capacity.

pub fn into_inner(self) -> Result<W, IntoInnerError<BufWriter<W>>>

Unwraps this BufWriter<W>, returning the underlying writer.

The buffer is written out before returning the writer.

Errors

An Err will be returned if an error occurs while flushing the buffer.

pub fn into_parts( self, ) -> (W, Result<Vec<u8, DEFAULT_BUF_SIZE, u16>, WriterPanicked>)

Disassembles this BufWriter<W>, returning the underlying writer, and any buffered but unwritten data.

If the underlying writer panicked, it is not known what portion of the data was written. In this case, we return WriterPanicked for the buffered data (from which the buffer contents can still be recovered).

into_parts makes no attempt to flush data and cannot fail.

Source

impl<W: ?Sized + Write> BufWriter<W>

pub fn get_ref(&self) -> &W

Gets a reference to the underlying writer.

pub fn get_mut(&mut self) -> &mut W

Gets a mutable reference to the underlying writer.

It is inadvisable to directly write to the underlying writer.

pub fn buffer(&self) -> &[u8]

Returns a reference to the internally buffered data.

pub fn capacity(&self) -> usize

Returns the number of bytes the internal buffer can hold without flushing.