Chain

Struct Chain 

pub struct Chain<T, U> { /* private fields */ }
Adapter to chain together two readers.

This struct is generally created by calling chain on a reader. Please see the documentation of chain for more details.

See std::io::Chain for more details.

Implementations

Source

impl<T, U> Chain<T, U>

pub fn into_inner(self) -> (T, U)

Consumes the Chain, returning the wrapped readers.

pub fn get_ref(&self) -> (&T, &U)

Gets references to the underlying readers in this Chain.

Care should be taken to avoid modifying the internal I/O state of the underlying readers as doing so may corrupt the internal state of this Chain.

pub fn get_mut(&mut self) -> (&mut T, &mut U)

Gets mutable references to the underlying readers in this Chain.

Care should be taken to avoid modifying the internal I/O state of the underlying readers as doing so may corrupt the internal state of this Chain.