Cursor

Struct Cursor 

pub struct Cursor<T> { /* private fields */ }
A Cursor wraps an in-memory buffer and provides it with a Seek implementation.

Cursors are used with in-memory buffers, anything implementing AsRef<[u8]>, to allow them to implement Read and/or Write, allowing these buffers to be used anywhere you might use a reader or writer that does actual I/O.

Implementations

Source

impl<T> Cursor<T>

pub const fn new(inner: T) -> Cursor<T>

Creates a new cursor wrapping the provided underlying in-memory buffer.

Cursor initial position is 0 even if underlying buffer (e.g., Vec) is not empty. So writing to cursor starts with overwriting Vec content, not with appending to it.

pub fn into_inner(self) -> T

Consumes this cursor, returning the underlying value.

pub const fn get_ref(&self) -> &T

Gets a reference to the underlying value in this cursor.

pub const fn get_mut(&mut self) -> &mut T

Gets a mutable reference to the underlying value in this cursor.

Care should be taken to avoid modifying the internal I/O state of the underlying value as it may corrupt this cursor’s position.

pub const fn position(&self) -> u64

Returns the current position of this cursor.

pub const fn set_position(&mut self, pos: u64)

Sets the position of this cursor.

Source

impl<T> Cursor<T>
where T: AsRef<[u8]>,

pub fn split(&self) -> (&[u8], &[u8])

Splits the underlying slice at the cursor position and returns them.

Source

impl<T> Cursor<T>
where T: AsMut<[u8]>,

pub fn split_mut(&mut self) -> (&mut [u8], &mut [u8])

Splits the underlying slice at the cursor position and returns them mutably.