LineWriter

Struct LineWriter 

pub struct LineWriter<W: ?Sized + Write> { /* private fields */ }
The BufWriter struct wraps a writer and buffers its output. But it only does this batched write when it goes out of scope, or when the internal buffer is full. Sometimes, you’d prefer to write each line as it’s completed, rather than the entire buffer at once. Enter LineWriter. It does exactly that.

Like BufWriter, a LineWriter’s buffer will also be flushed when the LineWriter goes out of scope or when its internal buffer is full.

If there’s still a partial line in the buffer when the LineWriter is dropped, it will flush those contents.

See std::io::LineWriter for more details.

Implementations

Source

impl<W: Write> LineWriter<W>

pub fn new(inner: W) -> LineWriter<W>

Creates a new LineWriter.

pub fn into_inner(self) -> Result<W, IntoInnerError<LineWriter<W>>>

Unwraps this LineWriter, returning the underlying writer.

The internal buffer is written out before returning the writer.

Errors

An Err will be returned if an error occurs while flushing the buffer.

Source

impl<W: ?Sized + Write> LineWriter<W>

pub fn get_ref(&self) -> &W

Gets a reference to the underlying writer.

pub fn get_mut(&mut self) -> &mut W

Gets a mutable reference to the underlying writer.

Caution must be taken when calling methods on the mutable reference returned as extra writes could corrupt the output stream.