Take

Struct Take 

pub struct Take<T> { /* private fields */ }
Reader adapter which limits the bytes read from an underlying reader.

This struct is generally created by calling take on a reader. Please see the documentation of take for more details.

See std::io::Take for more details.

Implementations

Source

impl<T> Take<T>

pub fn limit(&self) -> u64

Returns the number of bytes that can be read before this instance will return EOF.

pub fn position(&self) -> u64

Returns the number of bytes read so far.

pub fn set_limit(&mut self, limit: u64)

Sets the number of bytes that can be read before this instance will return EOF. This is the same as constructing a new Take instance, so the amount of bytes read and the previous limit value don’t matter when calling this method.

pub fn into_inner(self) -> T

Consumes the Take, returning the wrapped reader.

pub fn get_ref(&self) -> &T

Gets a reference to the underlying reader.

Care should be taken to avoid modifying the internal I/O state of the underlying reader as doing so may corrupt the internal limit of this Take.

pub fn get_mut(&mut self) -> &mut T

Gets a mutable reference to the underlying reader.

Care should be taken to avoid modifying the internal I/O state of the underlying reader as doing so may corrupt the internal limit of this Take.