pub struct WriterPanicked { /* private fields */ }Expand description
Error returned for the buffered data from BufWriter::into_parts, when the underlying
writer has previously panicked. Contains the (possibly partly written) buffered data.
Implementations
Sourceimpl WriterPanicked
impl WriterPanicked
Sourcepub fn into_inner(self) -> Vec<u8, DEFAULT_BUF_SIZE, u16>
pub fn into_inner(self) -> Vec<u8, DEFAULT_BUF_SIZE, u16>
Returns the perhaps-unwritten data. Some of this data may have been written by the panicking call(s) to the underlying writer, so simply writing it again is not a good idea.