pub struct BufWriter<W: ?Sized + Write> { /* private fields */ }Expand description
Wraps a writer and buffers its output.
See std::io::BufWriter for more details.
Implementations
Sourceimpl<W: Write> BufWriter<W>
impl<W: Write> BufWriter<W>
Sourcepub fn new(inner: W) -> BufWriter<W>
pub fn new(inner: W) -> BufWriter<W>
Creates a new BufWriter<W> with a default buffer capacity.
Sourcepub fn into_inner(self) -> Result<W, IntoInnerError<BufWriter<W>>>
pub fn into_inner(self) -> Result<W, IntoInnerError<BufWriter<W>>>
Sourcepub fn into_parts(
self,
) -> (W, Result<Vec<u8, DEFAULT_BUF_SIZE, u16>, WriterPanicked>)
pub fn into_parts( self, ) -> (W, Result<Vec<u8, DEFAULT_BUF_SIZE, u16>, WriterPanicked>)
Disassembles this BufWriter<W>, returning the underlying writer, and any buffered but
unwritten data.
If the underlying writer panicked, it is not known what portion of the data was written.
In this case, we return WriterPanicked for the buffered data (from which the buffer
contents can still be recovered).
into_parts makes no attempt to flush data and cannot fail.