pub struct Chain<T, U> { /* private fields */ }Expand description
Adapter to chain together two readers.
This struct is generally created by calling chain on a reader.
Please see the documentation of chain for more details.
See std::io::Chain for more details.
Implementations
Sourceimpl<T, U> Chain<T, U>
impl<T, U> Chain<T, U>
Sourcepub fn into_inner(self) -> (T, U)
pub fn into_inner(self) -> (T, U)
Consumes the Chain, returning the wrapped readers.