pub struct Cursor<T> { /* private fields */ }Expand description
Implementations
Sourceimpl<T> Cursor<T>
impl<T> Cursor<T>
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Consumes this cursor, returning the underlying value.
Sourcepub const fn get_mut(&mut self) -> &mut T
pub const fn get_mut(&mut self) -> &mut T
Gets a mutable reference to the underlying value in this cursor.
Care should be taken to avoid modifying the internal I/O state of the underlying value as it may corrupt this cursor’s position.
Sourcepub const fn set_position(&mut self, pos: u64)
pub const fn set_position(&mut self, pos: u64)
Sets the position of this cursor.