pub struct LineWriter<W: ?Sized + Write> { /* private fields */ }Expand description
The BufWriter struct wraps a writer and buffers its output.
But it only does this batched write when it goes out of scope, or when the
internal buffer is full. Sometimes, you’d prefer to write each line as it’s
completed, rather than the entire buffer at once. Enter LineWriter. It
does exactly that.
Like BufWriter, a LineWriter’s buffer will also be flushed when the
LineWriter goes out of scope or when its internal buffer is full.
If there’s still a partial line in the buffer when the LineWriter is
dropped, it will flush those contents.
See std::io::LineWriter for more details.
Implementations
Sourceimpl<W: Write> LineWriter<W>
impl<W: Write> LineWriter<W>
Sourcepub fn new(inner: W) -> LineWriter<W>
pub fn new(inner: W) -> LineWriter<W>
Creates a new LineWriter.
Sourcepub fn into_inner(self) -> Result<W, IntoInnerError<LineWriter<W>>>
pub fn into_inner(self) -> Result<W, IntoInnerError<LineWriter<W>>>
Sourceimpl<W: ?Sized + Write> LineWriter<W>
impl<W: ?Sized + Write> LineWriter<W>