pub struct Take<T> { /* private fields */ }Expand description
Reader adapter which limits the bytes read from an underlying reader.
This struct is generally created by calling take on a reader.
Please see the documentation of take for more details.
See std::io::Take for more details.
Implementations
Sourceimpl<T> Take<T>
impl<T> Take<T>
Sourcepub fn limit(&self) -> u64
pub fn limit(&self) -> u64
Returns the number of bytes that can be read before this instance will return EOF.
Sourcepub fn set_limit(&mut self, limit: u64)
pub fn set_limit(&mut self, limit: u64)
Sets the number of bytes that can be read before this instance will
return EOF. This is the same as constructing a new Take instance, so
the amount of bytes read and the previous limit value don’t matter when
calling this method.
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Consumes the Take, returning the wrapped reader.